==> haskell-foundation-0.0.21-8-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-foundation.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: foundation
version: 0.0.21
id: foundation-0.0.21-ERZ4SnvWQQb6CkFkcVo1oX
key: foundation-0.0.21-ERZ4SnvWQQb6CkFkcVo1oX
license: BSD-3-Clause
copyright: 2015-2017 Vincent Hanquez <vincent@snarc.org>, 2017- Foundation Maintainers
maintainer: vincent@snarc.org
author: Vincent Hanquez <vincent@snarc.org>
homepage: https://github.com/haskell-foundation/foundation
synopsis: Alternative prelude with batteries and no dependencies
description:
    A custom prelude with no dependencies apart from base.
    .
    This package has the following goals:
    .
    * provide a base like sets of modules that provide a consistent set of features and bugfixes across multiple versions of GHC (unlike base).
    .
    * provide a better and more efficient prelude than base'\''s prelude.
    .
    * be self-sufficient: no external dependencies apart from base.
    .
    * provide better data-types: packed unicode string by default, arrays.
    .
    * Better numerical classes that better represent mathematical thing (No more all-in-one Num).
    .
    * Better I/O system with less Lazy IO
    .
    * Usual partial functions distinguished through type system
category: foundation
abi: 30963ff76f10b3db3cf29cd2428e8b75
exposed: True
exposed-modules:
    Foundation Foundation.Array Foundation.Array.Internal
    Foundation.Bits Foundation.Check Foundation.Check.Main
    Foundation.Class.Bifunctor Foundation.Class.Storable
    Foundation.Collection Foundation.Conduit Foundation.Conduit.Textual
    Foundation.Exception Foundation.Foreign Foundation.Format.CSV
    Foundation.Hashing Foundation.IO Foundation.IO.FileMap
    Foundation.IO.Terminal Foundation.List.DList Foundation.List.ListN
    Foundation.Math.Trigonometry Foundation.Monad
    Foundation.Monad.Except Foundation.Monad.Reader
    Foundation.Monad.State Foundation.Network.IPv4
    Foundation.Network.IPv6 Foundation.Numerical Foundation.Parser
    Foundation.Primitive Foundation.Random Foundation.Strict
    Foundation.String Foundation.String.Builder Foundation.String.Read
    Foundation.System.Bindings Foundation.System.Bindings.Linux
    Foundation.System.Bindings.Posix
    Foundation.System.Bindings.PosixDef Foundation.System.Entropy
    Foundation.System.Info Foundation.Time.Bindings
    Foundation.Time.StopWatch Foundation.Time.Types Foundation.Timing
    Foundation.Timing.Main Foundation.Tuple.Nth Foundation.UUID
    Foundation.VFS Foundation.VFS.FilePath Foundation.VFS.Path
    Foundation.VFS.URI
hidden-modules: Foundation.Tuple Foundation.Hashing.FNV
                Foundation.Hashing.SipHash Foundation.Hashing.Hasher
                Foundation.Hashing.Hashable Foundation.Check.Gen
                Foundation.Check.Print Foundation.Check.Arbitrary
                Foundation.Check.Property Foundation.Check.Config
                Foundation.Check.Types Foundation.Collection.Buildable
                Foundation.Collection.List Foundation.Collection.Element
                Foundation.Collection.InnerFunctor Foundation.Collection.Collection
                Foundation.Collection.Copy Foundation.Collection.Sequential
                Foundation.Collection.Keyed Foundation.Collection.Indexed
                Foundation.Collection.Foldable Foundation.Collection.Mutable
                Foundation.Collection.Zippable Foundation.Collection.Mappable
                Foundation.Conduit.Internal Foundation.Format.CSV.Types
                Foundation.Format.CSV.Builder Foundation.Format.CSV.Parser
                Foundation.Numerical.Floating Foundation.IO.File
                Foundation.Monad.MonadIO Foundation.Monad.Exception
                Foundation.Monad.Transformer Foundation.Monad.Identity
                Foundation.Monad.Base Foundation.Random.Class Foundation.Random.DRG
                Foundation.Random.ChaChaDRG Foundation.Random.XorShift
                Foundation.Array.Chunked.Unboxed Foundation.Array.Bitmap
                Foundation.Foreign.Alloc Foundation.Foreign.MemoryMap
                Foundation.Foreign.MemoryMap.Types Foundation.Partial
                Foundation.System.Entropy.Common Foundation.System.Bindings.Network
                Foundation.System.Bindings.Time Foundation.System.Bindings.Hs
                Foundation.Foreign.MemoryMap.Posix Foundation.System.Entropy.Unix
import-dirs: /usr/lib/ghc-8.4.3/site-local/foundation-0.0.21
library-dirs: /usr/lib/ghc-8.4.3/site-local/foundation-0.0.21
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/foundation-0.0.21
hs-libraries: HSfoundation-0.0.21-ERZ4SnvWQQb6CkFkcVo1oX
depends:
    basement-0.0.8-8QjArDsw3GWCcbHE5iqtz3 base-4.11.1.0
    ghc-prim-0.5.2.0
abi-depends: basement-0.0.8-8QjArDsw3GWCcbHE5iqtz3=9715ac3eb77e5b1e262e646bd5991736
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             ghc-prim-0.5.2.0=387aa7e78e4e6c49e51798e4d6763c3f
haddock-interfaces: /usr/share/doc/haskell-foundation/html/foundation.haddock
haddock-html: /usr/share/doc/haskell-foundation/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-foundation-0.0.21-14-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-foundation.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: foundation
version: 0.0.21
id: foundation-0.0.21-5NxxYYSoWqyCaOYvoHYm2G
key: foundation-0.0.21-5NxxYYSoWqyCaOYvoHYm2G
license: BSD-3-Clause
copyright: 2015-2017 Vincent Hanquez <vincent@snarc.org>, 2017- Foundation Maintainers
maintainer: vincent@snarc.org
author: Vincent Hanquez <vincent@snarc.org>
homepage: https://github.com/haskell-foundation/foundation
synopsis: Alternative prelude with batteries and no dependencies
description:
    A custom prelude with no dependencies apart from base.
    .
    This package has the following goals:
    .
    * provide a base like sets of modules that provide a consistent set of features and bugfixes across multiple versions of GHC (unlike base).
    .
    * provide a better and more efficient prelude than base'\''s prelude.
    .
    * be self-sufficient: no external dependencies apart from base.
    .
    * provide better data-types: packed unicode string by default, arrays.
    .
    * Better numerical classes that better represent mathematical thing (No more all-in-one Num).
    .
    * Better I/O system with less Lazy IO
    .
    * Usual partial functions distinguished through type system
category: foundation
abi: b524212df84ac332173b91ad20e702e0
exposed: True
exposed-modules:
    Foundation Foundation.Array Foundation.Array.Internal
    Foundation.Bits Foundation.Check Foundation.Check.Main
    Foundation.Class.Bifunctor Foundation.Class.Storable
    Foundation.Collection Foundation.Conduit Foundation.Conduit.Textual
    Foundation.Exception Foundation.Foreign Foundation.Format.CSV
    Foundation.Hashing Foundation.IO Foundation.IO.FileMap
    Foundation.IO.Terminal Foundation.List.DList Foundation.List.ListN
    Foundation.Math.Trigonometry Foundation.Monad
    Foundation.Monad.Except Foundation.Monad.Reader
    Foundation.Monad.State Foundation.Network.IPv4
    Foundation.Network.IPv6 Foundation.Numerical Foundation.Parser
    Foundation.Primitive Foundation.Random Foundation.Strict
    Foundation.String Foundation.String.Builder Foundation.String.Read
    Foundation.System.Bindings Foundation.System.Bindings.Linux
    Foundation.System.Bindings.Posix
    Foundation.System.Bindings.PosixDef Foundation.System.Entropy
    Foundation.System.Info Foundation.Time.Bindings
    Foundation.Time.StopWatch Foundation.Time.Types Foundation.Timing
    Foundation.Timing.Main Foundation.Tuple.Nth Foundation.UUID
    Foundation.VFS Foundation.VFS.FilePath Foundation.VFS.Path
    Foundation.VFS.URI
hidden-modules: Foundation.Tuple Foundation.Hashing.FNV
                Foundation.Hashing.SipHash Foundation.Hashing.Hasher
                Foundation.Hashing.Hashable Foundation.Check.Gen
                Foundation.Check.Print Foundation.Check.Arbitrary
                Foundation.Check.Property Foundation.Check.Config
                Foundation.Check.Types Foundation.Collection.Buildable
                Foundation.Collection.List Foundation.Collection.Element
                Foundation.Collection.InnerFunctor Foundation.Collection.Collection
                Foundation.Collection.Copy Foundation.Collection.Sequential
                Foundation.Collection.Keyed Foundation.Collection.Indexed
                Foundation.Collection.Foldable Foundation.Collection.Mutable
                Foundation.Collection.Zippable Foundation.Collection.Mappable
                Foundation.Conduit.Internal Foundation.Format.CSV.Types
                Foundation.Format.CSV.Builder Foundation.Format.CSV.Parser
                Foundation.Numerical.Floating Foundation.IO.File
                Foundation.Monad.MonadIO Foundation.Monad.Exception
                Foundation.Monad.Transformer Foundation.Monad.Identity
                Foundation.Monad.Base Foundation.Random.Class Foundation.Random.DRG
                Foundation.Random.ChaChaDRG Foundation.Random.XorShift
                Foundation.Array.Chunked.Unboxed Foundation.Array.Bitmap
                Foundation.Foreign.Alloc Foundation.Foreign.MemoryMap
                Foundation.Foreign.MemoryMap.Types Foundation.Partial
                Foundation.System.Entropy.Common Foundation.System.Bindings.Network
                Foundation.System.Bindings.Time Foundation.System.Bindings.Hs
                Foundation.Foreign.MemoryMap.Posix Foundation.System.Entropy.Unix
import-dirs: /usr/lib/ghc-8.6.1/site-local/foundation-0.0.21
library-dirs: /usr/lib/ghc-8.6.1/site-local/foundation-0.0.21
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/foundation-0.0.21
hs-libraries: HSfoundation-0.0.21-5NxxYYSoWqyCaOYvoHYm2G
depends:
    base-4.12.0.0 basement-0.0.8-LdnmevtSRu4FZXxmMQJlGY ghc-prim-0.5.3
haddock-interfaces: /usr/share/doc/haskell-foundation/html/foundation.haddock
haddock-html: /usr/share/doc/haskell-foundation/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
